(no commit message)
[atyndall/cits2231.git] / scene.c
diff --git a/scene.c b/scene.c
index b986212..18f711d 100644 (file)
--- a/scene.c
+++ b/scene.c
@@ -464,12 +464,18 @@ void makeMenu() {
  * @param height New height\r
  */\r
 void windowReshape(int width, int height) {\r
-  glViewport(0, 0, (GLsizei)width, (GLsizei)height);\r
+  /*glViewport(0, 0, (GLsizei)width, (GLsizei)height);\r
   printf("Width: %d, height: %d\n", width, height);\r
   glMatrixMode(GL_PROJECTION);\r
   glLoadIdentity();\r
-  gluPerspective(60, (GLfloat)width / (GLfloat)height, 0.1, 1000.0);\r
+  gluPerspective( 60 * ((GLfloat)height/(GLfloat)width), (GLfloat)width/(GLfloat)height, 0.1, 1000.0);\r
   glMatrixMode(GL_MODELVIEW);\r
+\r
+  GLdouble near = 0.1;\r
+  GLdouble far = 1000.0;\r
+  GLdouble a = (GLfloat)height/(GLfloat)width;\r
+  GLdouble fov = 60;\r
+  glFrustum( -a*near*tan(fov/2),  a*near*tan(fov/2),  -a*near*tan(fov/2),  a*near*tan(fov/2), near, far  )*/\r
 }\r
 \r
 /**\r
@@ -490,7 +496,7 @@ void display() {
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);\r
    glLoadIdentity();\r
 \r
-   glTranslatef(0.0f,0.0f,-3.0f);                 // Move Left 1.5 Units And Into The Screen 6.0\r
+   glTranslatef(0.0f,0.0f,-10.0f); // Move into the Screen 10.0\r
 \r
    glutSolidTeapot(1);\r
 \r

UCC git Repository :: git.ucc.asn.au